==> dokuwiki_0.0.20131208.orig.tar.gz: dokuwiki-2013-12-08/lib/plugins/acl/lang/eu/lang.php <==
<?php
/**
 * Basque language file
 *
 * @author Inko Illarramendi <inko.i.a@gmail.com>
 * @author Zigor Astarbe <astarbe@gmail.com>
 */
$lang['admin_acl']             = 'Atzipen Kontrol Listaren Kudeaketa';
$lang['acl_group']             = 'Taldea';
$lang['acl_user']              = 'Erabiltzailea';
$lang['acl_perms']             = 'Baimenak honetarako:';
$lang['page']                  = 'Orria';
$lang['namespace']             = 'Izen-espazioa';
$lang['btn_select']            = 'Aukeratu';
$lang['p_user_id']             = '<b class="acluser">%s</b> erabiltzaileak une honetan honako baimenak ditu <b class="aclpage">%s</b> orrian: <i>%s</i>.';
$lang['p_user_ns']             = '<b class="acluser">%s</b> erabiltzaileak une honetan honako baimenak ditu <b class="aclns">%s</b> izen-espazioan: <i>%s</i>.';
$lang['p_group_id']            = '<b class="aclgroup">%s</b> taldeko kideek une honetan honako baimenak dituzte <b class="aclpage">%s</b> orrian: <i>%s</i>.';
$lang['p_group_ns']            = '<b class="aclgroup">%s</b> taldeko kideek une honetan honako baimenak dituzte <b class="aclns">%s</b> izen-espazioan: <i>%s</i>.';
$lang['p_choose_id']           = 'Mesedez <b>sartu erabiltzaile edo taldea</b> goiko formularioan <b class="aclpage">%s</b> orrian ezarritako baimenak ikusi edo aldatzeko.';
$lang['p_choose_ns']           = 'Mesedez <b>sartu erabiltzaile edo taldea</b> goiko formularioan <b class="aclns">%s</b> izen-espazioan ezarritako baimenak ikusi edo aldatzeko.';
$lang['p_inherited']           = 'Oharra: Baimen horiek ez dira esplizituki jarriak, beste talde batzuetatik edo goragoko izen-espazioetatik heredatuak baizik.';
$lang['p_isadmin']             = 'Oharra: Aukeratutako talde edo erabiltzaileak beti daika baimen osoa, supererabiltzaile gisa konfiguratuta  baitago.';
$lang['p_include']             = 'Baimen handiagoek baimen txikiagoak barneratzen dituzte. Sortu, Igo eta Ezabatu baimenak izen-espazioei soilik aplikatzen zaizkie, ez orriei.';
$lang['current']               = 'Uneko AKL Arauak';
$lang['where']                 = 'Orria/Izen-espazioa';
$lang['who']                   = 'Erabiltzailea/Taldea';
$lang['perm']                  = 'Baimenak';
$lang['acl_perm0']             = 'Inork';
$lang['acl_perm1']             = 'Irakurri';
$lang['acl_perm2']             = 'Editatu';
$lang['acl_perm4']             = 'Sortu';
$lang['acl_perm8']             = 'Igo';
$lang['acl_perm16']            = 'Ezabatu';
$lang['acl_new']               = 'Sarrera berri bat gehitu';
$lang['acl_mod']               = 'Aldatu Sarrera';

==> dokuwiki_0.0.20180422.a.orig.tar.gz: dokuwiki-2018-04-22a/lib/plugins/acl/lang/eu/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Inko Illarramendi <inko.i.a@gmail.com>
 * @author Zigor Astarbe <astarbe@gmail.com>
 */
$lang['admin_acl']             = 'Atzipen Kontrol Listaren Kudeaketa';
$lang['acl_group']             = 'Taldea:';
$lang['acl_user']              = 'Erabiltzailea:';
$lang['acl_perms']             = 'Baimenak honetarako:';
$lang['page']                  = 'Orria';
$lang['namespace']             = 'Izen-espazioa';
$lang['btn_select']            = 'Aukeratu';
$lang['p_user_id']             = '<b class="acluser">%s</b> erabiltzaileak une honetan honako baimenak ditu <b class="aclpage">%s</b> orrian: <i>%s</i>.';
$lang['p_user_ns']             = '<b class="acluser">%s</b> erabiltzaileak une honetan honako baimenak ditu <b class="aclns">%s</b> izen-espazioan: <i>%s</i>.';
$lang['p_group_id']            = '<b class="aclgroup">%s</b> taldeko kideek une honetan honako baimenak dituzte <b class="aclpage">%s</b> orrian: <i>%s</i>.';
$lang['p_group_ns']            = '<b class="aclgroup">%s</b> taldeko kideek une honetan honako baimenak dituzte <b class="aclns">%s</b> izen-espazioan: <i>%s</i>.';
$lang['p_choose_id']           = 'Mesedez <b>sartu erabiltzaile edo taldea</b> goiko formularioan <b class="aclpage">%s</b> orrian ezarritako baimenak ikusi edo aldatzeko.';
$lang['p_choose_ns']           = 'Mesedez <b>sartu erabiltzaile edo taldea</b> goiko formularioan <b class="aclns">%s</b> izen-espazioan ezarritako baimenak ikusi edo aldatzeko.';
$lang['p_inherited']           = 'Oharra: Baimen horiek ez dira esplizituki jarriak, beste talde batzuetatik edo goragoko izen-espazioetatik heredatuak baizik.';
$lang['p_isadmin']             = 'Oharra: Aukeratutako talde edo erabiltzaileak beti daika baimen osoa, supererabiltzaile gisa konfiguratuta  baitago.';
$lang['p_include']             = 'Baimen handiagoek baimen txikiagoak barneratzen dituzte. Sortu, Igo eta Ezabatu baimenak izen-espazioei soilik aplikatzen zaizkie, ez orriei.';
$lang['current']               = 'Uneko AKL Arauak';
$lang['where']                 = 'Orria/Izen-espazioa';
$lang['who']                   = 'Erabiltzailea/Taldea';
$lang['perm']                  = 'Baimenak';
$lang['acl_perm0']             = 'Inork';
$lang['acl_perm1']             = 'Irakurri';
$lang['acl_perm2']             = 'Editatu';
$lang['acl_perm4']             = 'Sortu';
$lang['acl_perm8']             = 'Igo';
$lang['acl_perm16']            = 'Ezabatu';
$lang['acl_new']               = 'Sarrera berri bat gehitu';
$lang['acl_mod']               = 'Aldatu Sarrera';
